@@ -7,9 +7,8 @@
 
 use std::path::PathBuf;
 
-use abscissa_core::{
-    config::Override, Command, Configurable, FrameworkError, Help, Options, Runnable,
-};
+use abscissa_core::{config::Override, Clap, Command, Configurable, FrameworkError, Runnable};
+use clap::AppSettings::Hidden;
 use tracing::{error, info};
 
 use crate::DEFAULT_CONFIG_PATH;
@@ -40,59 +39,58 @@ pub fn default_config_file() -> Option<PathBuf> {
 }
 
 /// Cli Subcommands
-#[derive(Command, Debug, Options, Runnable)]
+#[derive(Command, Clap, Debug, Runnable)]
 pub enum CliCmd {
-    /// The `help` subcommand
-    #[options(help = "Get usage information")]
-    Help(Help<Self>),
-
     /// The `config` subcommand
-    #[options(help = "Validate Hermes configuration file")]
+    #[clap(subcommand, about = "Validate Hermes configuration file")]
     Config(ConfigCmd),
 
     /// The `keys` subcommand
-    #[options(help = "Manage keys in the relayer for each chain")]
+    #[clap(subcommand, about = "Manage keys in the relayer for each chain")]
     Keys(KeysCmd),
 
     /// The `create` subcommand
-    #[options(help = "Create objects (client, connection, or channel) on chains")]
+    #[clap(
+        subcommand,
+        about = "Create objects (client, connection, or channel) on chains"
+    )]
     Create(CreateCmds),
 
     /// The `update` subcommand
-    #[options(help = "Update objects (clients) on chains")]
+    #[clap(subcommand, about = "Update objects (clients) on chains")]
     Update(UpdateCmds),
 
     /// The `upgrade` subcommand
-    #[options(help = "Upgrade objects (clients) after chain upgrade")]
+    #[clap(subcommand, about = "Upgrade objects (clients) after chain upgrade")]
     Upgrade(UpgradeCmds),
 
     /// The `start` subcommand
-    #[options(help = "Start the relayer in multi-chain mode. \
+    #[clap(about = "Start the relayer in multi-chain mode. \
                       Relays packets and open handshake messages between all chains in the config.")]
     Start(StartCmd),
 
     /// The `query` subcommand
-    #[options(help = "Query objects from the chain")]
+    #[clap(subcommand, about = "Query objects from the chain")]
     Query(QueryCmd),
 
     /// The `tx` subcommand
-    #[options(help = "Create and send IBC transactions")]
+    #[clap(subcommand, about = "Create and send IBC transactions")]
     Tx(TxCmd),
 
     /// The `listen` subcommand
-    #[options(help = "Listen to and display IBC events emitted by a chain")]
+    #[clap(about = "Listen to and display IBC events emitted by a chain")]
     Listen(ListenCmd),
 
     /// The `misbehaviour` subcommand
-    #[options(help = "Listen to client update IBC events and handles misbehaviour")]
+    #[clap(about = "Listen to client update IBC events and handles misbehaviour")]
     Misbehaviour(MisbehaviourCmd),
 
-    /// The `version` subcommand
-    #[options(help = "Display version information")]
+    /// The `version` subcommand, retained for backward compatibility.
+    #[clap(setting(Hidden))]
     Version(VersionCmd),
 
     /// The `health` subcommand
-    #[options(help = "Performs a health check of all chains in the the config")]
+    #[clap(about = "Performs a health check of all chains in the the config")]
     HealthCheck(HealthCheckCmd),
 }
 
@@ -135,7 +133,7 @@ impl Configurable<Config> for CliCmd {
     fn process_config(&self, mut config: Config) -> Result<Config, FrameworkError> {
         // Alter the memo for all chains to include a suffix with Hermes build details
         let web = "https://hermes.informal.systems";
-        let suffix = format!("{} {} ({})", CliCmd::name(), CliCmd::version(), web);
+        let suffix = format!("{} {} ({})", CliCmd::name(), clap::crate_version!(), web);
         for ccfg in config.chains.iter_mut() {
             ccfg.memo_prefix.apply_suffix(&suffix);
         }
