@@ -1,6 +1,6 @@
 use core::time::Duration;
 
-use abscissa_core::{Command, Options, Runnable};
+use abscissa_core::{Clap, Command, Runnable};
 
 use ibc::core::ics02_client::client_state::ClientState;
 use ibc::core::ics24_host::identifier::{ChainId, ClientId};
@@ -13,34 +13,33 @@ use crate::cli_utils::{spawn_chain_runtime, ChainHandlePair};
 use crate::conclude::{exit_with_unrecoverable_error, Output};
 use crate::prelude::*;
 
-#[derive(Clone, Command, Debug, Options)]
+#[derive(Clone, Command, Debug, Clap)]
 pub struct CreateConnectionCommand {
-    #[options(
-        free,
-        required,
-        help = "identifier of the side `a` chain for the new connection"
+    #[clap(
+        required = true,
+        about = "identifier of the side `a` chain for the new connection"
     )]
     chain_a_id: ChainId,
 
-    #[options(free, help = "identifier of the side `b` chain for the new connection")]
+    #[clap(about = "identifier of the side `b` chain for the new connection")]
     chain_b_id: Option<ChainId>,
 
-    #[options(
-        help = "identifier of client hosted on chain `a`; default: None (creates a new client)",
-        no_short
+    #[clap(
+        long,
+        about = "identifier of client hosted on chain `a`; default: None (creates a new client)"
     )]
     client_a: Option<ClientId>,
 
-    #[options(
-        help = "identifier of client hosted on chain `b`; default: None (creates a new client)",
-        no_short
+    #[clap(
+        long,
+        about = "identifier of client hosted on chain `b`; default: None (creates a new client)"
     )]
     client_b: Option<ClientId>,
 
-    #[options(
-        help = "delay period parameter for the new connection (seconds)",
-        default = "0",
-        no_short
+    #[clap(
+        long,
+        about = "delay period parameter for the new connection (seconds)",
+        default_value = "0"
     )]
     delay: u64,
 }
