@@ -1,4 +1,4 @@
-use abscissa_core::{Command, Options, Runnable};
+use abscissa_core::{Clap, Command, Runnable};
 
 use ibc::core::ics24_host::identifier::ChainId;
 use ibc_relayer::{
@@ -9,15 +9,15 @@ use ibc_relayer::{
 use crate::application::app_config;
 use crate::conclude::Output;
 
-#[derive(Clone, Command, Debug, Options)]
+#[derive(Clone, Command, Debug, Clap)]
 pub struct KeysDeleteCmd {
-    #[options(free, required, help = "identifier of the chain")]
+    #[clap(required = true, about = "identifier of the chain")]
     chain_id: ChainId,
 
-    #[options(short = "n", help = "name of the key")]
+    #[clap(short = 'n', long, about = "name of the key")]
     name: Option<String>,
 
-    #[options(short = "a", help = "delete all keys")]
+    #[clap(short = 'a', long, about = "delete all keys")]
     all: bool,
 }
 
