@@ -1,6 +1,6 @@
 use core::str::FromStr;
 
-use abscissa_core::{Command, Options, Runnable};
+use abscissa_core::{Clap, Command, Runnable};
 
 use ibc::core::ics24_host::identifier::ChainId;
 use ibc_relayer::{
@@ -11,24 +11,31 @@ use ibc_relayer::{
 use crate::application::app_config;
 use crate::conclude::Output;
 
-#[derive(Clone, Command, Debug, Options)]
+#[derive(Clone, Command, Debug, Clap)]
 pub struct KeyRestoreCmd {
-    #[options(free, required, help = "identifier of the chain")]
+    #[clap(required = true, about = "identifier of the chain")]
     chain_id: ChainId,
 
-    #[options(short = "m", required, help = "mnemonic to restore the key from")]
+    #[clap(
+        short = 'm',
+        long,
+        required = true,
+        about = "mnemonic to restore the key from"
+    )]
     mnemonic: String,
 
-    #[options(
-        short = "n",
-        help = "name of the key (defaults to the `key_name` defined in the config)"
+    #[clap(
+        short = 'n',
+        long,
+        about = "name of the key (defaults to the `key_name` defined in the config)"
     )]
     name: Option<String>,
 
-    #[options(
-        short = "p",
-        help = "derivation path for this key",
-        default = "m/44'/118'/0'/0/0"
+    #[clap(
+        short = 'p',
+        long,
+        about = "derivation path for this key",
+        default_value = "m/44'/118'/0'/0/0"
     )]
     hd_path: String,
 }
