@@ -1,6 +1,6 @@
 //! `query` subcommand
 
-use abscissa_core::{Command, Options, Runnable};
+use abscissa_core::{Clap, Command, Runnable};
 
 use crate::commands::query::channel_ends::QueryChannelEndsCmd;
 use crate::commands::query::channels::QueryChannelsCmd;
@@ -17,77 +17,77 @@ mod packet;
 mod tx;
 
 /// `query` subcommand
-#[derive(Command, Debug, Options, Runnable)]
+#[derive(Command, Debug, Clap, Runnable)]
 pub enum QueryCmd {
     /// The `query client` subcommand
-    #[options(help = "Query information about clients")]
+    #[clap(subcommand, about = "Query information about clients")]
     Client(QueryClientCmds),
 
-    #[options(help = "Query the identifiers of all clients on a chain")]
+    #[clap(about = "Query the identifiers of all clients on a chain")]
     Clients(clients::QueryAllClientsCmd),
 
     /// The `query connection` subcommand
-    #[options(help = "Query information about connections")]
+    #[clap(subcommand, about = "Query information about connections")]
     Connection(QueryConnectionCmds),
 
     /// The `query connections` subcommand
-    #[options(help = "Query the identifiers of all connections on a chain")]
+    #[clap(about = "Query the identifiers of all connections on a chain")]
     Connections(connections::QueryConnectionsCmd),
 
     /// The `query channel` subcommand
-    #[options(help = "Query information about channels")]
+    #[clap(subcommand, about = "Query information about channels")]
     Channel(QueryChannelCmds),
 
     /// The `query channels` subcommand
-    #[options(help = "Query the identifiers of all channels on a given chain")]
+    #[clap(about = "Query the identifiers of all channels on a given chain")]
     Channels(QueryChannelsCmd),
 
     /// The `query packet` subcommand
-    #[options(help = "Query information about packets")]
+    #[clap(subcommand, about = "Query information about packets")]
     Packet(QueryPacketCmds),
 
     /// The `query tx` subcommand
-    #[options(help = "Query information about transactions")]
+    #[clap(subcommand, about = "Query information about transactions")]
     Tx(tx::QueryTxCmd),
 }
 
-#[derive(Command, Debug, Options, Runnable)]
+#[derive(Command, Debug, Clap, Runnable)]
 pub enum QueryClientCmds {
     /// The `query client state` subcommand
-    #[options(help = "Query the client full state")]
+    #[clap(about = "Query the client full state")]
     State(client::QueryClientStateCmd),
 
     /// The `query client consensus` subcommand
-    #[options(help = "Query the client consensus state")]
+    #[clap(about = "Query the client consensus state")]
     Consensus(client::QueryClientConsensusCmd),
 
     /// The `query client header` subcommand
-    #[options(help = "Query for the header used in a client update at a certain height")]
+    #[clap(about = "Query for the header used in a client update at a certain height")]
     Header(client::QueryClientHeaderCmd),
 
     /// The `query client connections` subcommand
-    #[options(help = "Query the client connections")]
+    #[clap(about = "Query the client connections")]
     Connections(client::QueryClientConnectionsCmd),
 }
 
-#[derive(Command, Debug, Options, Runnable)]
+#[derive(Command, Debug, Clap, Runnable)]
 pub enum QueryConnectionCmds {
     /// The `query connection end` subcommand
-    #[options(help = "Query connection end")]
+    #[clap(about = "Query connection end")]
     End(connection::QueryConnectionEndCmd),
 
     /// The `query connection channels` subcommand
-    #[options(help = "Query connection channels")]
+    #[clap(about = "Query connection channels")]
     Channels(connection::QueryConnectionChannelsCmd),
 }
 
-#[derive(Command, Debug, Options, Runnable)]
+#[derive(Command, Debug, Clap, Runnable)]
 pub enum QueryChannelCmds {
     /// The `query channel end` subcommand
-    #[options(help = "Query channel end")]
+    #[clap(about = "Query channel end")]
     End(channel::QueryChannelEndCmd),
 
     /// The `query channel ends` subcommand
-    #[options(help = "Query channel ends and underlying connection and client objects")]
+    #[clap(about = "Query channel ends and underlying connection and client objects")]
     Ends(QueryChannelEndsCmd),
 }
