@@ -1,4 +1,4 @@
-use abscissa_core::{Command, Options, Runnable};
+use abscissa_core::{Clap, Command, Runnable};
 
 use ibc::core::ics03_connection::connection::ConnectionEnd;
 use ibc::core::ics04_channel::channel::Order;
@@ -45,24 +45,29 @@ macro_rules! tx_chan_cmd {
     };
 }
 
-#[derive(Clone, Command, Debug, Options)]
+#[derive(Clone, Command, Debug, Clap)]
 pub struct TxRawChanOpenInitCmd {
-    #[options(free, required, help = "identifier of the destination chain")]
+    #[clap(required = true, about = "identifier of the destination chain")]
     dst_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the source chain")]
+    #[clap(required = true, about = "identifier of the source chain")]
     src_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the destination connection")]
+    #[clap(required = true, about = "identifier of the destination connection")]
     dst_conn_id: ConnectionId,
 
-    #[options(free, required, help = "identifier of the destination port")]
+    #[clap(required = true, about = "identifier of the destination port")]
     dst_port_id: PortId,
 
-    #[options(free, required, help = "identifier of the source port")]
+    #[clap(required = true, about = "identifier of the source port")]
     src_port_id: PortId,
 
-    #[options(help = "the channel ordering, valid options 'unordered' (default) and 'ordered'")]
+    #[clap(
+        short,
+        long,
+        default_value_t,
+        about = "the channel ordering, valid options 'unordered' (default) and 'ordered'"
+    )]
     order: Order,
 }
 
@@ -93,6 +98,7 @@ impl Runnable for TxRawChanOpenInitCmd {
                 ConnectionId::default(),
                 self.src_port_id.clone(),
                 None,
+                None,
             ),
             b_side: ChannelSide::new(
                 chains.dst,
@@ -100,8 +106,8 @@ impl Runnable for TxRawChanOpenInitCmd {
                 self.dst_conn_id.clone(),
                 self.dst_port_id.clone(),
                 None,
+                None,
             ),
-            version: None,
         };
 
         info!("Message ChanOpenInit: {:?}", channel);
@@ -117,88 +123,43 @@ impl Runnable for TxRawChanOpenInitCmd {
     }
 }
 
-#[derive(Clone, Command, Debug, Options)]
+#[derive(Clone, Command, Debug, Clap)]
 pub struct TxRawChanOpenTryCmd {
-    #[options(free, required, help = "identifier of the destination chain")]
+    #[clap(required = true, about = "identifier of the destination chain")]
     dst_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the source chain")]
+    #[clap(required = true, about = "identifier of the source chain")]
     src_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the destination connection")]
+    #[clap(required = true, about = "identifier of the destination connection")]
     dst_conn_id: ConnectionId,
 
-    #[options(free, required, help = "identifier of the destination port")]
+    #[clap(required = true, about = "identifier of the destination port")]
     dst_port_id: PortId,
 
-    #[options(free, required, help = "identifier of the source port")]
+    #[clap(required = true, about = "identifier of the source port")]
     src_port_id: PortId,
 
-    #[options(
-        required,
-        help = "identifier of the source channel (required)",
-        short = "s",
-        meta = "ID"
+    #[clap(
+        short = 's',
+        long,
+        required = true,
+        about = "identifier of the source channel (required)",
+        value_name = "ID"
     )]
     src_chan_id: ChannelId,
 
-    #[options(
-        help = "identifier of the destination channel (optional)",
-        short = "d",
-        meta = "ID"
+    #[clap(
+        short = 'd',
+        long,
+        about = "identifier of the destination channel (optional)",
+        value_name = "ID"
     )]
     dst_chan_id: Option<ChannelId>,
 }
 
 impl Runnable for TxRawChanOpenTryCmd {
     fn run(&self) {
-        let config = app_config();
-
-        let chains = match ChainHandlePair::spawn(&config, &self.src_chain_id, &self.dst_chain_id) {
-            Ok(chains) => chains,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
-        };
-
-        // Retrieve the connection
-        let dst_connection = match chains
-            .dst
-            .query_connection(&self.dst_conn_id, Height::default())
-        {
-            Ok(connection) => connection,
-            Err(e) => return Output::error(format!("{}", e)).exit(),
-        };
-
-        let channel = Channel {
-            connection_delay: Default::default(),
-            ordering: Order::default(),
-            a_side: ChannelSide::new(
-                chains.src,
-                ClientId::default(),
-                ConnectionId::default(),
-                self.src_port_id.clone(),
-                Some(self.src_chan_id.clone()),
-            ),
-            b_side: ChannelSide::new(
-                chains.dst,
-                dst_connection.client_id().clone(),
-                self.dst_conn_id.clone(),
-                self.dst_port_id.clone(),
-                self.dst_chan_id.clone(),
-            ),
-            version: None,
-        };
-
-        info!("Message ChanOpenTry: {:?}", channel);
-
-        let res: Result<IbcEvent, Error> = channel
-            .build_chan_open_try_and_send()
-            .map_err(Error::channel);
-
-        match res {
-            Ok(receipt) => Output::success(receipt).exit(),
-            Err(e) => Output::error(format!("{}", e)).exit(),
-        }
-
         tx_chan_cmd!(
             "ChanOpenTry",
             build_chan_open_try_and_send,
@@ -213,6 +174,7 @@ impl Runnable for TxRawChanOpenTryCmd {
                         ConnectionId::default(),
                         self.src_port_id.clone(),
                         Some(self.src_chan_id.clone()),
+                        None,
                     ),
                     b_side: ChannelSide::new(
                         chains.dst,
@@ -220,44 +182,46 @@ impl Runnable for TxRawChanOpenTryCmd {
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
                         self.dst_chan_id.clone(),
+                        None,
                     ),
-                    version: None,
                 }
             }
         );
     }
 }
 
-#[derive(Clone, Command, Debug, Options)]
+#[derive(Clone, Command, Debug, Clap)]
 pub struct TxRawChanOpenAckCmd {
-    #[options(free, required, help = "identifier of the destination chain")]
+    #[clap(required = true, about = "identifier of the destination chain")]
     dst_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the source chain")]
+    #[clap(required = true, about = "identifier of the source chain")]
     src_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the destination connection")]
+    #[clap(required = true, about = "identifier of the destination connection")]
     dst_conn_id: ConnectionId,
 
-    #[options(free, required, help = "identifier of the destination port")]
+    #[clap(required = true, about = "identifier of the destination port")]
     dst_port_id: PortId,
 
-    #[options(free, required, help = "identifier of the source port")]
+    #[clap(required = true, about = "identifier of the source port")]
     src_port_id: PortId,
 
-    #[options(
-        required,
-        help = "identifier of the destination channel (required)",
-        short = "d",
-        meta = "ID"
+    #[clap(
+        short = 'd',
+        long,
+        required = true,
+        about = "identifier of the destination channel (required)",
+        value_name = "ID"
     )]
     dst_chan_id: ChannelId,
 
-    #[options(
-        required,
-        help = "identifier of the source channel (required)",
-        short = "s",
-        meta = "ID"
+    #[clap(
+        short = 's',
+        long,
+        required = true,
+        about = "identifier of the source channel (required)",
+        value_name = "ID"
     )]
     src_chan_id: ChannelId,
 }
@@ -278,6 +242,7 @@ impl Runnable for TxRawChanOpenAckCmd {
                         ConnectionId::default(),
                         self.src_port_id.clone(),
                         Some(self.src_chan_id.clone()),
+                        None,
                     ),
                     b_side: ChannelSide::new(
                         chains.dst,
@@ -285,44 +250,46 @@ impl Runnable for TxRawChanOpenAckCmd {
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
                         Some(self.dst_chan_id.clone()),
+                        None,
                     ),
-                    version: None,
                 }
             }
         );
     }
 }
 
-#[derive(Clone, Command, Debug, Options)]
+#[derive(Clone, Command, Debug, Clap)]
 pub struct TxRawChanOpenConfirmCmd {
-    #[options(free, required, help = "identifier of the destination chain")]
+    #[clap(required = true, about = "identifier of the destination chain")]
     dst_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the source chain")]
+    #[clap(required = true, about = "identifier of the source chain")]
     src_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the destination connection")]
+    #[clap(required = true, about = "identifier of the destination connection")]
     dst_conn_id: ConnectionId,
 
-    #[options(free, required, help = "identifier of the destination port")]
+    #[clap(required = true, about = "identifier of the destination port")]
     dst_port_id: PortId,
 
-    #[options(free, required, help = "identifier of the source port")]
+    #[clap(required = true, about = "identifier of the source port")]
     src_port_id: PortId,
 
-    #[options(
-        required,
-        help = "identifier of the destination channel (required)",
-        short = "d",
-        meta = "ID"
+    #[clap(
+        short = 'd',
+        long,
+        required = true,
+        about = "identifier of the destination channel (required)",
+        value_name = "ID"
     )]
     dst_chan_id: ChannelId,
 
-    #[options(
-        required,
-        help = "identifier of the source channel (required)",
-        short = "s",
-        meta = "ID"
+    #[clap(
+        short = 's',
+        long,
+        required = true,
+        about = "identifier of the source channel (required)",
+        value_name = "ID"
     )]
     src_chan_id: ChannelId,
 }
@@ -343,6 +310,7 @@ impl Runnable for TxRawChanOpenConfirmCmd {
                         ConnectionId::default(),
                         self.src_port_id.clone(),
                         Some(self.src_chan_id.clone()),
+                        None,
                     ),
                     b_side: ChannelSide::new(
                         chains.dst,
@@ -350,44 +318,46 @@ impl Runnable for TxRawChanOpenConfirmCmd {
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
                         Some(self.dst_chan_id.clone()),
+                        None,
                     ),
-                    version: None,
                 }
             }
         );
     }
 }
 
-#[derive(Clone, Command, Debug, Options)]
+#[derive(Clone, Command, Debug, Clap)]
 pub struct TxRawChanCloseInitCmd {
-    #[options(free, required, help = "identifier of the destination chain")]
+    #[clap(required = true, about = "identifier of the destination chain")]
     dst_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the source chain")]
+    #[clap(required = true, about = "identifier of the source chain")]
     src_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the destination connection")]
+    #[clap(required = true, about = "identifier of the destination connection")]
     dst_conn_id: ConnectionId,
 
-    #[options(free, required, help = "identifier of the destination port")]
+    #[clap(required = true, about = "identifier of the destination port")]
     dst_port_id: PortId,
 
-    #[options(free, required, help = "identifier of the source port")]
+    #[clap(required = true, about = "identifier of the source port")]
     src_port_id: PortId,
 
-    #[options(
-        required,
-        help = "identifier of the destination channel (required)",
-        short = "d",
-        meta = "ID"
+    #[clap(
+        short = 'd',
+        long,
+        required = true,
+        about = "identifier of the destination channel (required)",
+        value_name = "ID"
     )]
     dst_chan_id: ChannelId,
 
-    #[options(
-        required,
-        help = "identifier of the source channel (required)",
-        short = "s",
-        meta = "ID"
+    #[clap(
+        short = 's',
+        long,
+        required = true,
+        about = "identifier of the source channel (required)",
+        value_name = "ID"
     )]
     src_chan_id: ChannelId,
 }
@@ -408,6 +378,7 @@ impl Runnable for TxRawChanCloseInitCmd {
                         ConnectionId::default(),
                         self.src_port_id.clone(),
                         Some(self.src_chan_id.clone()),
+                        None,
                     ),
                     b_side: ChannelSide::new(
                         chains.dst,
@@ -415,44 +386,46 @@ impl Runnable for TxRawChanCloseInitCmd {
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
                         Some(self.dst_chan_id.clone()),
+                        None,
                     ),
-                    version: None,
                 }
             }
         );
     }
 }
 
-#[derive(Clone, Command, Debug, Options)]
+#[derive(Clone, Command, Debug, Clap)]
 pub struct TxRawChanCloseConfirmCmd {
-    #[options(free, required, help = "identifier of the destination chain")]
+    #[clap(required = true, about = "identifier of the destination chain")]
     dst_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the source chain")]
+    #[clap(required = true, about = "identifier of the source chain")]
     src_chain_id: ChainId,
 
-    #[options(free, required, help = "identifier of the destination connection")]
+    #[clap(required = true, about = "identifier of the destination connection")]
     dst_conn_id: ConnectionId,
 
-    #[options(free, required, help = "identifier of the destination port")]
+    #[clap(required = true, about = "identifier of the destination port")]
     dst_port_id: PortId,
 
-    #[options(free, required, help = "identifier of the source port")]
+    #[clap(required = true, about = "identifier of the source port")]
     src_port_id: PortId,
 
-    #[options(
-        required,
-        help = "identifier of the destination channel (required)",
-        short = "d",
-        meta = "ID"
+    #[clap(
+        short = 'd',
+        long,
+        required = true,
+        about = "identifier of the destination channel (required)",
+        value_name = "ID"
     )]
     dst_chan_id: ChannelId,
 
-    #[options(
-        required,
-        help = "identifier of the source channel (required)",
-        short = "s",
-        meta = "ID"
+    #[clap(
+        short = 's',
+        long,
+        required = true,
+        about = "identifier of the source channel (required)",
+        value_name = "ID"
     )]
     src_chan_id: ChannelId,
 }
@@ -473,6 +446,7 @@ impl Runnable for TxRawChanCloseConfirmCmd {
                         ConnectionId::default(),
                         self.src_port_id.clone(),
                         Some(self.src_chan_id.clone()),
+                        None,
                     ),
                     b_side: ChannelSide::new(
                         chains.dst,
@@ -480,8 +454,8 @@ impl Runnable for TxRawChanCloseConfirmCmd {
                         self.dst_conn_id.clone(),
                         self.dst_port_id.clone(),
                         Some(self.dst_chan_id.clone()),
+                        None,
                     ),
-                    version: None,
                 }
             }
         );
